@@ -1,5 +1,8 @@
 #include <stdlib.h>
 #include <math.h>
+#ifdef _OPENMP
+#include <omp.h>
+#endif
 
 int Suivant(int nbchiffres, int base, int *chiffres);
 
